==> KleckFiles(5.80.00).zip: KleckFiles/html/KF_LIST.js <==
// video shorts
var _shortVidsList = ['230518-02', '230331-02', '230329', '230528-01', '230809', 
						'230725-02', '230709', '230722', '230806-01', '230730', '230807-01',
					   '230810', '230811', '230725-01', '230821', '230826', '230830', '230901',
						'230902', '231002', "231014-02", "231016", "231017", "231021",
						"231024-02", "231025", "231030"];

// Explore / Favorites
var __Favs = [
	{name: "Getting Started", videos : ['190316', '190320', '181114']},
	{name: "Personal testimony", videos : ['130725', '110710-03']},
   
	{name: "Acts of Peter / Snare", videos : ['151103', '151105', '180702', '180721-02', '201221']},
	{name: "Know Your Enemy", videos : ['190709-P01', '170505']},
	{name: "Upside down", videos : ['180323-P04', '120913-01', '151103', '160711-01', '160925-01', '161228', '170921-02', '171023-02', '181023', '220321']},
	{name: "Mystery Solved", videos : ['180817']},
	{name: "Shapeshifters", videos : ['171104', '171105']},
	{name: "Unveiling", videos : ['190324']},
	{name: "System of control", videos : ['171022', '171023-01', '171023-02', '171024', '171026-01', '171026-02', '171027', '171031', '171101', '171102']},
	{name: "911", videos : ['120910-02', '140809', '160413', '160808-02', '160826-02', '161120', '180130-02', '180218', '180725', '180916', '181023']},
	{name: "Mark of the beast", videos : ['121012', '121212', '170727', '170728', '180505-01', '180806-02', '191225', '200102-02', '200330', '200515', '200518', '210821', '220727', '220803-03']},
	{name: "The Deed", videos : ['160528', '160529-01', '160529-02', '160529-03', '160529-04']},
	{name: "Mystery Babylon", videos : ['120327-01', '120327-02', '120327-03', '120327-05', '120327-06', '120327-07', '120327-08', '120327-09', '120327-10', '120327-11', '120327-12']},
	{name: "Cannibalism", videos : ['170214-02', '170222-02', '170224', '170227', '170314', '180131-03', '180621', '200929']},
	{name: "Serpent", videos : ['130820', '151225', '180304-01', '180304-02', '180304-03', '180306-01', '180330', '180331', '180410-02', '180410-03']},
	{name: "Barack", videos : ['130213', '130214', '140213', '171109-01', '180312', '180908']},
	{name: "Seth Rich", videos : ['170716']},
	{name: "Missiles", videos : ['120915', '120923']},
	{name: "Man in our image", videos : ['210405-01', '210405-02', '210405-03', '210406-01', '210406-02', '210407-01', '210407-02']},
	{name: "Enemy at the gate series", videos : ['140823', '140824', '140826-01', '140826-02', '140827-01', '140827-02', '140828', '140829-01', '140829-02', '140830', '140831', '140901', '140902']},
	{name: "Thy kingdom come", videos : ['150902', '150904-01', '150904-02', '150905-01', '150905-02', '150905-03', '150906']},
	
	{name: "Bugs", videos : ['170601-02']},
	{name: "More Gems", videos : ['170126-02', '210612']},
	{id: "myfav", name: 'MY FAVORITES <span style="font-size:110%;">☆</span>', 
	 videos : [], desc : "This section shows you KleckFiles videos that you have marked as favorites (FireFox / local PC may not work)."}
	];

==> KleckFiles(5.98.00).zip: KleckFiles/html/KF_LIST.js <==
// video shorts
var _shortVidsList = ['230518-02', '230331-02', '230329', '230528-01', '230809', 
						'230725-02', '230709', '230722', '230806-01', '230730', '230807-01',
					   '230810', '230811', '230725-01', '230821', '230826', '230830', '230901',
						'230902', '231002', "231014-02", "231016", "231017", "231021",
						"231024-02", "231025", "231030", "231109", "231110", "231120"];

// Explore / Favorites
var __Favs = [
	{name: "Getting Started", videos : ['190316', '190320', '181114']},
	{name: "Personal testimony", videos : ['130725', '110710-03']},
   
	{name: "Acts of Peter / Snare", videos : ['151103', '151105', '180702', '180721-02', '201221']},
	{name: "Know Your Enemy", videos : ['190709-P01', '170505']},
	{name: "Upside down", videos : ['180323-P04', '120913-01', '151103', '160711-01', '160925-01', '161228', '170921-02', '171023-02', '181023', '220321']},
	{name: "Mystery Solved", videos : ['180817']},
	{name: "Shapeshifters", videos : ['171104', '171105']},
	{name: "Unveiling", videos : ['190324']},
	{name: "System of control", videos : ['171022', '171023-01', '171023-02', '171024', '171026-01', '171026-02', '171027', '171031', '171101', '171102']},
	{name: "911", videos : ['120910-02', '140809', '160413', '160808-02', '160826-02', '161120', '180130-02', '180218', '180725', '180916', '181023']},
	{name: "Mark of the beast", videos : ['121012', '121212', '170727', '170728', '180505-01', '180806-02', '191225', '200102-02', '200330', '200515', '200518', '210821', '220727', '220803-03']},
	{name: "The Deed", videos : ['160528', '160529-01', '160529-02', '160529-03', '160529-04']},
	{name: "Mystery Babylon", videos : ['120327-01', '120327-02', '120327-03', '120327-05', '120327-06', '120327-07', '120327-08', '120327-09', '120327-10', '120327-11', '120327-12']},
	{name: "Cannibalism", videos : ['170214-02', '170222-02', '170224', '170227', '170314', '180131-03', '180621', '200929']},
	{name: "Serpent", videos : ['130820', '151225', '180304-01', '180304-02', '180304-03', '180306-01', '180330', '180331', '180410-02', '180410-03']},
	{name: "Barack", videos : ['130213', '130214', '140213', '171109-01', '180312', '180908']},
	{name: "Seth Rich", videos : ['170716']},
	{name: "Missiles", videos : ['120915', '120923']},
	{name: "Man in our image", videos : ['210405-01', '210405-02', '210405-03', '210406-01', '210406-02', '210407-01', '210407-02']},
	{name: "Enemy at the gate series", videos : ['140823', '140824', '140826-01', '140826-02', '140827-01', '140827-02', '140828', '140829-01', '140829-02', '140830', '140831', '140901', '140902']},
	{name: "Thy kingdom come", videos : ['150902', '150904-01', '150904-02', '150905-01', '150905-02', '150905-03', '150906']},
	
	{name: "Bugs", videos : ['170601-02']},
	{name: "More Gems", videos : ['170126-02', '210612']},
	{id: "myfav", name: 'MY FAVORITES <span style="font-size:110%;">☆</span>', 
	 videos : [], desc : "This section shows you KleckFiles videos that you have marked as favorites (FireFox / local PC may not work)."}
	];
